@@ -152,6 +152,10 @@ KNSBackend::KNSBackend(QObject* parent, const QString& iconName, const QString &
     connect(m_engine, &KNSCore::Engine::signalEntryChanged, this, &KNSBackend::statusChanged, Qt::QueuedConnection);
     connect(m_engine, &KNSCore::Engine::signalEntryDetailsLoaded, this, &KNSBackend::detailsLoaded);
     connect(m_engine, &KNSCore::Engine::signalProvidersLoaded, this, &KNSBackend::fetchInstalled);
+    connect(m_engine, &KNSCore::Engine::signalUpdateableEntriesLoaded, this, [this] {
+        m_responsePending = false;
+        Q_EMIT availableForQueries();
+    });
     connect(m_engine, &KNSCore::Engine::signalCategoriesMetadataLoded, this, [categories] (const QList<KNSCore::Provider::CategoryMetadata>& categoryMetadatas){
         for (const KNSCore::Provider::CategoryMetadata& category : categoryMetadatas) {
             for (Category* cat : qAsConst(categories)) {
@@ -205,6 +209,8 @@ KNSBackend::KNSBackend(QObject* parent, const QString& iconName, const QString &
         auto addonsCategory = new Category(topLevelName, iconName, filters, backendName, {actualCategory}, QUrl(), true);
         m_rootCategories = { addonsCategory };
     }
+
+    connect(m_updater, &StandardBackendUpdater::updatesCountChanged, this, &KNSBackend::updatesCountChanged);
 }
 
 KNSBackend::~KNSBackend()
@@ -383,8 +389,25 @@ void KNSBackend::signalErrorCode(const KNSCore::ErrorCode& errorCode, const QStr
             invalidFile = true;
             break;
         case KNSCore::ErrorCode::InstallationError:
-            // This error is handled already, by forwarding the KNS engine's installer error message.
+        {
+            KNSResource* r = static_cast<KNSResource*>(m_resourcesByName.value(metadata.toString()));
+            if (r) {
+                // If the following is true, then we can safely assume that the entry was
+                // attempted updated, but the update was aborted.
+                // Specifically, we can also likely expect that the update failed because
+                // KNSCore::Engine was unable to deduce which payload to use (which will
+                // happen when an entry has more than one payload, and none of those match
+                // the name of the originally downloaded file).
+                // We cannot complete this in Discover (as we've no way to forward that
+                // query to the user) but we can give them an idea of how to deal with the
+                // situation some other way.
+                // TODO: Once Discover has a way to forward queries to the user from transactions, this likely will no longer be needed
+                if (r->entry().status() == KNS3::Entry::Updateable) {
+                    error = i18n("Unable to complete the update of %1. You can try and perform this action through the Get Hot New Stuff dialog, which grants tighter control. The reported error was:\n%2", r->name(), message);
+                }
+            }
             break;
+        }
         case KNSCore::ErrorCode::ImageError:
             // Image fetching errors are not critical as such, but may lead to weird layout issues, might want handling...
             error = i18n("Could not fetch screenshot for the entry %1 in backend %2", metadata.toList().at(0).toString(), m_displayName);
@@ -570,11 +593,7 @@ ResultsStream * KNSBackend::findResourceByPackageName(const QUrl& search)
     if (search.scheme() != QLatin1String("kns") || search.host() != name())
         return voidStream();
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    const auto pathParts = search.path().split(QLatin1Char('/'), QString::SkipEmptyParts);
-#else
     const auto pathParts = search.path().split(QLatin1Char('/'), Qt::SkipEmptyParts);
-#endif
     if (pathParts.size() != 2) {
         Q_EMIT passiveMessage(i18n("Wrong KNewStuff URI: %1", search.toString()));
         return voidStream();
