@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright © 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 #include "KNSResource.h"
 #include "KNSBackend.h"
@@ -143,7 +129,7 @@ KNSCore::EntryInternal KNSResource::entry() const
 
 QJsonArray KNSResource::licenses()
 {
-    return { QJsonObject{ {QStringLiteral("name"), m_entry.license()} } };
+    return { QJsonObject{ {QStringLiteral("name"), m_entry.license()}, {QStringLiteral("url"), QString()} } };
 }
 
 int KNSResource::size()
@@ -154,12 +140,15 @@ int KNSResource::size()
 
 QString KNSResource::installedVersion() const
 {
-    return m_entry.version();
+    return !m_entry.version().isEmpty() ? m_entry.version() : m_entry.releaseDate().toString();
 }
 
 QString KNSResource::availableVersion() const
 {
-    return !m_entry.updateVersion().isEmpty() ? m_entry.updateVersion() : m_entry.version();
+    return !m_entry.updateVersion().isEmpty() ? m_entry.updateVersion()
+         : !m_entry.updateReleaseDate().isNull() ? m_entry.updateReleaseDate().toString()
+         : !m_entry.version().isEmpty() ? m_entry.version()
+         : releaseDate().toString();
 }
 
 QString KNSResource::origin() const
@@ -207,37 +196,24 @@ QStringList KNSResource::extends() const
     return knsBackend()->extends();
 }
 
-QStringList KNSResource::executables() const
-{
-    if (knsBackend()->engine()->hasAdoptionCommand())
-        return {knsBackend()->engine()->adoptionCommand(m_entry)};
-    else
-        return {};
-}
-
 QUrl KNSResource::url() const
 {
     return QUrl(QStringLiteral("kns://")+knsBackend()->name() + QLatin1Char('/') + QUrl(m_entry.providerId()).host() + QLatin1Char('/') + m_entry.uniqueId());
 }
 
+bool KNSResource::canExecute() const
+{
+    return knsBackend()->engine()->hasAdoptionCommand();
+}
+
 void KNSResource::invokeApplication() const
 {
-    QStringList exes = executables();
-    if(!exes.isEmpty()) {
-        const QString exe = exes.constFirst();
-        auto args = KShell::splitArgs(exe);
-        QProcess::startDetached(args.takeFirst(), args);
-    } else {
-        qWarning() << "cannot execute" << packageName();
-    }
+    knsBackend()->engine()->adoptEntry(m_entry);
 }
 
 QString KNSResource::executeLabel() const
 {
-    if(knsBackend()->hasApplications()) {
-        return i18n("Launch");
-    }
-    return i18n("Use");
+    return knsBackend()->engine()->useLabel();
 }
 
 QDate KNSResource::releaseDate() const
@@ -267,13 +243,13 @@ Rating * KNSResource::ratingInstance()
         const int noc = m_entry.numberOfComments();
         const int rating = m_entry.rating();
         Q_ASSERT(rating <= 100);
-        return new Rating(
+        m_rating.reset(new Rating(
             packageName(),
             noc,
-            { { QStringLiteral("star5"), rating } }
-        );
+            rating / 10
+        ));
     }
-    return m_rating;
+    return m_rating.data();
 }
 
 QString KNSResource::author() const
