@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright © 2013 Lukas Appelhans <l.appelhans@gmx.de>                 *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2013 Lukas Appelhans <l.appelhans@gmx.de>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 #ifndef PACKAGEKITUPDATER_H
 #define PACKAGEKITUPDATER_H
 
@@ -24,6 +10,8 @@
 #include "PackageKitBackend.h"
 #include <PackageKit/Transaction>
 
+class SystemUpgrade;
+
 int percentageWithStatus(PackageKit::Transaction::Status status, uint percentage);
 
 class PackageKitUpdater : public AbstractBackendUpdater
@@ -52,6 +40,7 @@ class PackageKitUpdater : public AbstractBackendUpdater
         quint64 downloadSpeed() const override;
 
         void proceed() override;
+        void setOfflineUpdates(bool use) override;
 
     public Q_SLOTS:
         ///must be implemented if ever isCancelable is true
@@ -61,7 +50,6 @@ class PackageKitUpdater : public AbstractBackendUpdater
     private Q_SLOTS:
         void errorFound(PackageKit::Transaction::Error err, const QString& error);
         void mediaChange(PackageKit::Transaction::MediaType media, const QString& type, const QString& text);
-        void requireRestart(PackageKit::Transaction::Restart restart, const QString& p);
         void eulaRequired(const QString &eulaID, const QString &packageID, const QString &vendor, const QString &licenseAgreement);
         void finished(PackageKit::Transaction::Exit exit, uint);
         void cancellableChanged();
@@ -86,7 +74,6 @@ class PackageKitUpdater : public AbstractBackendUpdater
         void lastUpdateTimeReceived(QDBusPendingCallWatcher* w);
         void setupTransaction(PackageKit::Transaction::TransactionFlags flags);
         bool useOfflineUpdates() const;
-        void setUseOfflineUpdates(bool use);
 
         QSet<QString> involvedPackages(const QSet<AbstractResource*>& packages) const;
         QSet<AbstractResource*> packagesForPackageId(const QSet<QString>& packages) const;
@@ -97,10 +84,13 @@ class PackageKitUpdater : public AbstractBackendUpdater
         QSet<AbstractResource*> m_allUpgradeable;
         bool m_isCancelable;
         bool m_isProgressing;
+        bool m_useOfflineUpdates = false;
         int m_percentage;
         QDateTime m_lastUpdate;
         QMap<PackageKit::Transaction::Info, QStringList> m_packagesModified;
         QVector<std::function<PackageKit::Transaction*()>> m_proceedFunctions;
+
+        SystemUpgrade* m_upgrade = nullptr;
 };
 
 
