@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright © 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 #include "ResourcesUpdatesModel.h"
 #include <Transaction/Transaction.h>
@@ -25,11 +11,12 @@
 #include "AbstractBackendUpdater.h"
 #include "AbstractResource.h"
 #include "utils.h"
-#include <QDateTime>
 #include "libdiscover_debug.h"
 
 #include <KLocalizedString>
 #include <KFormat>
+#include <KSharedConfig>
+#include <KConfigGroup>
 
 class UpdateTransaction : public Transaction
 {
@@ -105,7 +92,7 @@ public:
     }
 
     QVariant icon() const override { return QStringLiteral("update-low"); }
-    QString name() const override { return i18n("Update"); }
+    QString name() const override { return i18n("View Updates"); }
 
 Q_SIGNALS:
     void finished();
@@ -145,6 +132,11 @@ void ResourcesUpdatesModel::init()
         }
     }
 
+//     To enable from command line use:
+//     kwriteconfig5 --file discoverrc --group Software --key UseOfflineUpdates true
+    KConfigGroup group(KSharedConfig::openConfig(), "Software");
+    m_offlineUpdates = group.readEntry<bool>("UseOfflineUpdates", false);
+
     auto tm = TransactionModel::global();
     foreach(auto t, tm->transactions()) {
         auto updateTransaction = qobject_cast<UpdateTransaction*>(t);
@@ -173,7 +165,9 @@ void ResourcesUpdatesModel::prepare()
         qCWarning(LIBDISCOVER_LOG) << "trying to set up a running instance";
         return;
     }
+
     foreach(AbstractBackendUpdater* upd, m_updaters) {
+        upd->setOfflineUpdates(m_offlineUpdates);
         upd->prepare();
     }
 }
@@ -291,4 +285,9 @@ bool ResourcesUpdatesModel::needsReboot() const
     return false;
 }
 
+void ResourcesUpdatesModel::setOfflineUpdates(bool offline)
+{
+    m_offlineUpdates = offline;
+}
+
 #include "ResourcesUpdatesModel.moc"
