@@ -1,20 +1,7 @@
 /*
- *   Copyright (C) 2019 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+ *   SPDX-FileCopyrightText: 2019 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library/Lesser General Public License
- *   version 2, or (at your option) any later version, as published by the
- *   Free Software Foundation
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library/Lesser General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *   SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include <QApplication>
@@ -32,7 +19,6 @@
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
 #include <QDebug>
-#include "DiscoverNotifier.h"
 #include "../DiscoverVersion.h"
 
 #include "NotifierItem.h"
@@ -49,7 +35,7 @@ int main(int argc, char** argv)
     KDBusService::StartupOptions startup = {};
     {
         KAboutData about(QStringLiteral("DiscoverNotifier"), i18n("Discover Notifier"), version, i18n("System update status notifier"),
-                     KAboutLicense::GPL, i18n("© 2010-2019 Plasma Development Team"));
+                     KAboutLicense::GPL, i18n("© 2010-2020 Plasma Development Team"));
         about.addAuthor(QStringLiteral("Aleix Pol Gonzalez"), {}, QStringLiteral("aleixpol@kde.org"));
         about.setProductName("discover/discover");
         about.setProgramLogo(app.windowIcon());
